#!/usr/bin/env python3

"""
based on code from Nick Parlante for Stanford CS106A
"""

from utilities import draw_grid_canvas, start_timer, SIDE

import sys
import tkinter
import random
import drawcanvas

from byugrid import Grid

SIDE = 20  # pixels across of one square


def random_right(grid):
    """
    Set 10% of the right grid column to random letters from the word 'cougars'
    :param grid: a grid
    :return: the same grid, but with random letters on the right edge
    >>> grid1 = Grid.build([[None ], [None], [None], [None], [None], [None], [None], [None], [None], [None]])
    >>> random.seed(86)
    >>> random_right(grid1)
    [['a'], [None], ['s'], [None], [None], [None], [None], [None], [None], [None]]
    """
    for y in range(grid.height):
        if random.randrange(10) == 0:
            char = random.choice('cougars')
            grid.set(grid.width - 1, y, char)
    return grid


def scroll_left(grid):
    """
    Move every letter in the grid one cell left
    >>> grid1 = Grid.build([['a', 'b', 'c'], ['d', None, None]])
    >>> scroll_left(grid1)
    [['b', 'c', None], [None, None, None]]
    """
    # v1 - has bugs
    for y in range(grid.height):
        for x in range(grid.width):
            # get value at (x, y)
            value = grid.get(x, y)
            if value is not None and grid.in_bounds(x - 1, y):
                # move letter at (x, y) to the left
                grid.set(x - 1, y, value)
    return grid


# ************* Utility Functions Below here


def movie_action(grid, canvas):
    """Do one round of the move, call in timer."""
    random_right(grid)
    draw_grid_canvas(grid, canvas)
    scroll_left(grid)


def main():
    args = sys.argv[1:]

    width = 30
    height = 30
    # Can give width/height on command line
    if len(args) == 2:
        width = int(args[0])
        height = int(args[1])

    grid = Grid(width, height)

    canvas = drawcanvas.make_canvas(width * SIDE, height * SIDE, 'Movie')
    draw_grid_canvas(grid, canvas)

    start_timer(canvas, 30, lambda: movie_action(grid, canvas))

    tkinter.mainloop()


if __name__ == '__main__':
    main()
